@@ -266,7 +266,7 @@ class InputMediaWithThumb(InputMedia):
         # end if
     # end def
 
-    def __init__(self, type, media, thumb, caption=None, parse_mode=None, caption_entities=None):
+    def __init__(self, type, media, thumb=None, caption=None, parse_mode=None, caption_entities=None):
         """
         This object represents the content of a media message to be sent.
 
@@ -300,7 +300,7 @@ class InputMediaWithThumb(InputMedia):
 
         # 'type' is set by InputMedia base class
         # 'media' is set by InputMedia base class
-        assert_type_or_raise(thumb, InputFile, unicode_type, parameter_name="thumb")
+        assert_type_or_raise(thumb, None, InputFile, unicode_type, parameter_name="thumb")
         self.thumb = thumb
         # 'caption' is set by InputMedia base class
         # 'parse_mode' is set by InputMedia base class
@@ -328,7 +328,8 @@ class InputMediaWithThumb(InputMedia):
         if isinstance(self.thumb, InputFile):
             array['thumb'] = self.thumb.to_array()  # type InputFile
         elif isinstance(self.thumb, str):
-            array['thumb'] = u(self.thumb)  # py2: type unicode, py3: type strelse:
+            array['thumb'] = u(self.thumb)  # py2: type unicode, py3: type str
+        else:
             raise TypeError('Unknown type, must be one of InputFile, str.')
         # end if
         # 'caption' given by superclass
@@ -448,7 +449,7 @@ class InputMediaPlayable(InputMediaWithThumb):
 
 
 
-    def __init__(self, type, media, thumb, duration=None, caption=None, parse_mode=None, caption_entities=None):
+    def __init__(self, type, media, thumb=None, duration=None, caption=None, parse_mode=None, caption_entities=None):
         """
         This object represents the content of a media message to be sent.
 
@@ -635,7 +636,7 @@ class InputMediaVideolike(InputMediaPlayable):
 
 
 
-    def __init__(self, type, media, thumb, duration=None, width=None, height=None, caption=None, parse_mode=None, caption_entities=None):
+    def __init__(self, type, media, thumb=None, duration=None, width=None, height=None, caption=None, parse_mode=None, caption_entities=None):
         """
         This object represents the content of a media message to be sent.
 
@@ -1708,4 +1709,3 @@ class InputMediaDocument(InputMediaWithThumb):
         )
     # end def __contains__
 # end class InputMediaDocument
-
